cutty
=====

|PyPI| |Status| |Python Version| |License| |Read the Docs| |Tests| |Codecov|

.. |PyPI| image:: https://img.shields.io/pypi/v/cutty.svg
   :target: https://pypi.org/project/cutty/
   :alt: PyPI
.. |Status| image:: https://img.shields.io/pypi/status/cutty.svg
   :target: https://pypi.org/project/cutty/
   :alt: Status
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/cutty
   :target: https://pypi.org/project/cutty
   :alt: Python Version
.. |License| image:: https://img.shields.io/pypi/l/cutty
   :target: https://opensource.org/licenses/MIT
   :alt: License
.. |Read the Docs| image:: https://img.shields.io/readthedocs/cutty/latest.svg?label=Read%20the%20Docs
   :target: https://cutty.readthedocs.io/
   :alt: Read the documentation at https://cutty.readthedocs.io/
.. |Tests| image:: https://github.com/cjolowicz/cutty/workflows/Tests/badge.svg
   :target: https://github.com/cjolowicz/cutty/actions?workflow=Tests
   :alt: Tests
.. |Codecov| image:: https://codecov.io/gh/cjolowicz/cutty/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/cjolowicz/cutty
   :alt: Codecov


An experimental Cookiecutter clone :construction:


Requirements
------------

* Python 3.9


Installation
------------

You can install *cutty* via pip_ from PyPI_:

.. code:: console

   $ pip install cutty


Usage
-----

Please see the `Command-line Reference <Usage_>`_ for details.


Contributing
------------

Contributions are very welcome.
To learn more, see the `Contributor Guide`_.


License
-------

Distributed under the terms of the `MIT license`_,
*cutty* is free and open source software.


Issues
------

If you encounter any problems,
please `file an issue`_ along with a detailed description.


Credits
-------

This project was generated from `@cjolowicz`_'s `Hypermodern Python Cookiecutter`_ template.

.. _@cjolowicz: https://github.com/cjolowicz
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _MIT license: https://opensource.org/licenses/MIT
.. _PyPI: https://pypi.org/
.. _Hypermodern Python Cookiecutter: https://github.com/cjolowicz/cookiecutter-hypermodern-python
.. _file an issue: https://github.com/cjolowicz/cutty/issues
.. _pip: https://pip.pypa.io/
.. github-only
.. _Contributor Guide: CONTRIBUTING.rst
.. _Usage: https://cutty.readthedocs.io/en/latest/usage.html
